<?php
/**
 * Parallax Blog functions and definitions
 *
 * @package Parallax Blog
 */

if ( ! function_exists( 'parallax_blog_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function parallax_blog_setup() {

        add_image_size('pb-post-image',  80, 80, true);
        add_image_size('pb-blog-header',  900, 400, true);

        // Add support for full and wide align images.
        add_theme_support( 'align-wide' );
      
       // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'footer_menu' => esc_html__( 'Footer Menu', 'parallax-blog' )
        ) );

    }
endif;
add_action( 'after_setup_theme', 'parallax_blog_setup' );


function ap_para_blog_enqueue_styles() {

    wp_enqueue_style( 'ap-para-parent-style', get_template_directory_uri() . '/style.css' );

    $para_blog_font_args = array(
            'family' => 'Roboto:300,400,500,700,900');
    wp_enqueue_style( 'ap-para-google-fonts', add_query_arg( $para_blog_font_args, "//fonts.googleapis.com/css" ) );
    wp_enqueue_style( 'owl-carousel', get_stylesheet_directory_uri() . '/assets/css/owl.carousel.min.css' );
    wp_enqueue_style( 'owl-theme-default', get_stylesheet_directory_uri() . '/assets/css/owl.theme.default.min.css' );
    wp_enqueue_script( 'owl-carousel', get_stylesheet_directory_uri() . '/assets/js/owl.carousel.min.js', array('jquery'), '20151215', true );
    wp_enqueue_script( 'fitvids', get_stylesheet_directory_uri() . '/assets/js/jquery.fitvids.js', array( 'jquery' ), '20151215', true );
    wp_register_script( 'pb-custom-script', get_stylesheet_directory_uri() . '/assets/js/pb-custom.js', array('jquery'), '20151215', true );
    $enable_loading_post  = accesspress_parallax_of_get_option( 'enable_auto_loading_post',1 );
    $enable_parallax_effect  = accesspress_parallax_of_get_option( 'enable_parallax_effect',1 );

    $localize_options =  array(
        'ajaxurl'       => admin_url( 'admin-ajax.php'),
        'auto_load' => $enable_loading_post,
        'enable_para' => $enable_parallax_effect,
        );

    wp_localize_script( 'pb-custom-script', 'pb_ajax_script', $localize_options  );
    wp_enqueue_script( 'pb-custom-script' );

}
add_action( 'wp_enqueue_scripts', 'ap_para_blog_enqueue_styles' );

global $pagenow;
if (is_admin() && ('themes.php' == $pagenow) && (isset($_GET['activated']))) {
    add_action('admin_notices', "mytheme_setup_options");
}

if (!function_exists('mytheme_setup_options')) {

    function mytheme_setup_options() {
        if (file_exists(__DIR__ . "/inital.php")) {
            include(__DIR__ . "/inital.php");
        }
    }

}

if( ! function_exists('para_blog_cust_temp')){
    function para_blog_cust_temp($wp_customize){

// custom
$wp_customize->add_setting( 'accesspress_parallax[para_blog_custom]', array(
       'sanitize_callback'    => 'esc_attr', 'type' => 'option'
      ));
$wp_customize->add_control( new Parallax_Blog_Notice_Instruction( $wp_customize,'accesspress_parallax[para_blog_custom]', array(
        'section'         => 'accesspress_parallax_header_settings',
        'label'           => esc_html__('Parallax Blog Settings','accesspress-parallax'),
    	'priority'		  =>100
      )));

// Enable Posts on Menu
$wp_customize->add_setting( 'accesspress_parallax[enable_posts_on_menu]', array( 'default' => 1, 'type' => 'option', 'sanitize_callback' => 'parallax_blog_sanitize_checkbox' ) );
$wp_customize->add_control(
        'accesspress_parallax[enable_posts_on_menu]', array(
    'label' 		=> esc_html__( 'Enable Posts on Menu', 'accesspress-parallax' ),
    'description' 	=> /* translators: Menu Link*/ esc_html__( 'Check to enable latest post on menu.', 'accesspress-parallax' ),
    'type' 			=> 'checkbox',
    'priority'		=>100,
    'section' 		=> 'accesspress_parallax_header_settings',
) );

$wp_customize->add_setting( 'accesspress_parallax[post_display_type]', array( 'default' => 'latest-post','sanitize_callback' => 'para_blog_post_dis_typ', 'type' => 'option'
    ) );
$wp_customize->add_control( 'accesspress_parallax[post_display_type]', array(
	'section'			=> 'accesspress_parallax_header_settings',
	'label'				=> esc_html__( 'Select Posts Display Type', 'accesspress-parallax' ),
	'type'				=> 'radio',
	'priority'			=>100,
	'choices'			=> array(
		'latest-post'	=> esc_html__('Display From Latest Posts','accesspress-parallax'),
		'cat-post'		=> esc_html__('Display From Selected Category','accesspress-parallax')
	),

));

$cat_list = parallax_blog_category_lists();

$wp_customize->add_setting('accesspress_parallax[hd_post_menu_cat]', array(
    'default'			 => 0,
     'sanitize_callback' => 'para_blog_post_cat_typ', 
     'type' 			 => 'option'
    ) );
$wp_customize->add_control('accesspress_parallax[hd_post_menu_cat]', array(
	'section'			=> 'accesspress_parallax_header_settings',
	'label'				=> esc_html__( 'Select News Category', 'accesspress-parallax' ),
	'priority'			=>100,
	'type'				=> 'select',
	'active_callback'	=> 'para_blog_post_disp_typ',
	'choices'			=> $cat_list

));

// Enable Categories on Menu
$wp_customize->add_setting( 'accesspress_parallax[enable_cat_on_menu]', array( 'default' => 1, 'type' => 'option', 'sanitize_callback' => 'parallax_blog_sanitize_checkbox' ) );
$wp_customize->add_control(
        'accesspress_parallax[enable_cat_on_menu]', array(
    'label' 		=> esc_html__( 'Enable Categories on Menu', 'accesspress-parallax' ),
    'description' 	=> /* translators: Menu Link*/ esc_html__( 'Check to enable categories on latest post.', 'accesspress-parallax' ),
    'type' 			=> 'checkbox',
    'priority'		=>100,
    'section' 		=> 'accesspress_parallax_header_settings',
) );

//News ticker count
$wp_customize->add_setting('accesspress_parallax[no_of_posts]', array(
        'default' 			=> 4,
        'sanitize_callback' => 'absint', 
        'type' 				=> 'option'
   	)
);    
$wp_customize->add_control('accesspress_parallax[no_of_posts]',array(
        'type'			=> 'number',
        'label' 		=> esc_html__( 'Number of Posts', 'accesspress-parallax' ),
        'section' 		=> 'accesspress_parallax_header_settings',
		'priority'		=>100,
        'input_attrs' 	=> array(
            'min'   => 4,
            'max'   => 12,
            'step'  => 1
        )
    )
);


//Author Sections
$wp_customize->add_section( 'parallax_blog_blog_author', array(
    'title' => esc_html__( 'Author Settings', 'accesspress-parallax' ),
    'priority' => 2
) );

// Enable Author on Menu
$wp_customize->add_setting( 'accesspress_parallax[enable_author_on_menu]', array( 'default' => 1, 'type' => 'option', 'sanitize_callback' => 'parallax_blog_sanitize_checkbox' ) );
$wp_customize->add_control(
        'accesspress_parallax[enable_author_on_menu]', array(
    'label'         => esc_html__( 'Enable Author on Menu', 'accesspress-parallax' ),
    'description'   => /* translators: Menu Link*/ esc_html__( 'Check to enable author on menu.', 'accesspress-parallax' ),
    'type'          => 'checkbox',
    'section'       => 'parallax_blog_blog_author',
) );

//title
$wp_customize->add_setting('accesspress_parallax[author_title]', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field', 
        'type'              => 'option'
    )
);    
$wp_customize->add_control('accesspress_parallax[author_title]',array(
        'type'          => 'text',
        'label'         => esc_html__( 'Author Title', 'accesspress-parallax' ),
        'section'       => 'parallax_blog_blog_author',
    )
);
//logo
$wp_customize->add_setting('accesspress_parallax[author_logo]',array(
        'sanitize_callback' => 'esc_url_raw',
        'type'              => 'option'
));
$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'accesspress_parallax[author_logo]',array(
        'label'           => esc_html__( 'Author Logo', 'accesspress-parallax' ),
        'section'         => 'parallax_blog_blog_author',
)));

//image
$wp_customize->add_setting('accesspress_parallax[author_image]',array(
        'sanitize_callback' => 'esc_url_raw',
        'type'              => 'option'
));
$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'accesspress_parallax[author_image]',array(
        'label'           => esc_html__( 'Author Image', 'accesspress-parallax' ),
        'section'         => 'parallax_blog_blog_author',
)));

//description
$wp_customize->add_setting('accesspress_parallax[author_description]', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field', 
        'type'              => 'option'
    )
);    
$wp_customize->add_control('accesspress_parallax[author_description]',array(
        'type'          => 'textarea',
        'label'         => esc_html__( 'Author Description', 'accesspress-parallax' ),
        'section'       => 'parallax_blog_blog_author',
    )
);

//read more link
$wp_customize->add_setting('accesspress_parallax[read_more_link]', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field', 
        'type'              => 'option'
    )
);    
$wp_customize->add_control('accesspress_parallax[read_more_link]',array(
        'type'          => 'esc_url_raw',
        'label'         => esc_html__( 'Read More Link', 'accesspress-parallax' ),
        'section'       => 'parallax_blog_blog_author',
    )
);

//signature
$wp_customize->add_setting('accesspress_parallax[author_signature]',array(
      'sanitize_callback' => 'esc_url_raw',
      'type'              => 'option'
));
$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'accesspress_parallax[author_signature]',array(
      'label'           => esc_html__( 'Author Signature', 'accesspress-parallax' ),
      'section'         => 'parallax_blog_blog_author',
)));

//social icons
$social_icons = array('facebook','twitter','youtube','pinterest','instagram','linkedin','dribbble','soundcloud','dropbox');
foreach( $social_icons as $social_icon){
    
  $wp_customize->add_setting( 'accesspress_parallax[parallax_blog_'.$social_icon.'_url]', array(
        'sanitize_callback' => 'esc_url_raw',
        'type'              => 'option'
    ));
  $wp_customize->add_control( 'accesspress_parallax[parallax_blog_'.$social_icon.'_url]', array(
        'section'       => 'parallax_blog_blog_author',
        'label'         => esc_html__('Social Icon ','accesspress-parallax').$social_icon,
        'type'          => 'text'
    ));
}

//author copyright
$wp_customize->add_setting('accesspress_parallax[author_copyright]', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_text_field', 
        'type'              => 'option'
    )
);    
$wp_customize->add_control('accesspress_parallax[author_copyright]',array(
        'type'          => 'textarea',
        'label'         => esc_html__( 'Author Copyright', 'accesspress-parallax' ),
        'section'       => 'parallax_blog_blog_author',
    )
);


//Author Sections
$wp_customize->add_panel( 'parallax_blog_design_setting', array(
    'title' => esc_html__( 'Design Settings', 'accesspress-parallax' ),
    'priority' => 80
) );

//Archive Sections
$wp_customize->add_section( 'parallax_blog_archive_section', array(
    'title' => esc_html__( 'Archive Settings', 'accesspress-parallax' ),
    'panel' =>'parallax_blog_design_setting',
    'priority' => 10
) );

// Archive text excerpt
$wp_customize->add_setting( 'accesspress_parallax[archive_text_excerpt]', array( 'default' => 200, 'type' => 'option', 'sanitize_callback' => 'absint' ) );
$wp_customize->add_control(
        'accesspress_parallax[archive_text_excerpt]', array(
    'label'         => esc_html__( 'Archive Content Text', 'accesspress-parallax' ),
    'type'          => 'number',
    'section'       => 'parallax_blog_archive_section',
) );

// Enable Auto Loading Post
$wp_customize->add_setting( 'accesspress_parallax[enable_auto_loading_post]', array( 'default' => 1, 'type' => 'option', 'sanitize_callback' => 'parallax_blog_sanitize_checkbox' ) );
$wp_customize->add_control(
        'accesspress_parallax[enable_auto_loading_post]', array(
    'label'         => esc_html__( 'Enable Auto Loading Post', 'accesspress-parallax' ),
    'type'          => 'checkbox',
    'priority'      =>100,
    'section'       => 'accesspress_parallax_post_settings',
) );

//footer settings
$wp_customize->add_setting( 'accesspress_parallax[footer_copyright]', array(
  'sanitize_callback' => 'wp_kses_post',
  'type'              => 'option'
));

$wp_customize->add_control( 'accesspress_parallax[footer_copyright]', array(
  'label'     => esc_html__('Footer Copyright','accesspress-parallax'),
  'type'      => 'text',
  'section'   => 'accesspress_parallax_custom_footer'
));

}}
//apply_filters( 'para_blog_widget_template', 'para_blog_widget_template_cus' );

add_action( 'customize_register', 'para_blog_cust_temp' );


/**
* function to retrieve default categories from posts
*/
function parallax_blog_category_lists() {
    $categories = get_categories(
            array(
                'hide_empty' => 0,
                'exclude' => 1
            )
    );
    $category_list = array();
    $category_list[0] = esc_html__('Select Category', 'accesspress-parallax');
    foreach ($categories as $category) :
        $category_list[$category->term_id] = $category->name;
    endforeach;
    return $category_list;
}



require get_stylesheet_directory() . '/inc/init.php';

/**
 * Implement the Elementor
 */
if ( defined( 'ELEMENTOR_VERSION' ) ) {
   require get_stylesheet_directory() . '/inc/elementor/elementor.php';
}

// Sanitize Checkbox
function parallax_blog_sanitize_checkbox( $input, $setting ) {

    return ( ( isset( $input ) && true == $input ) ? true : false );
}

